@@ -2,19 +2,18 @@
 #
 # Copyright (C) 2013 Martin Owens
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
-# (at your option) any later version.
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 3.0 of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library.
 #
 """
 Test croniter extention to find out when items will next happen.
@@ -50,8 +49,12 @@ class CroniterTestCase(unittest.TestCase):
 
     def test_00_nocroniter(self):
         """No Croniter"""
-        # Remove croniter if importer before.
-        sys.modules.pop('croniter', None)
+        # Remove croniter if imported before.
+        for i in range(1, 4):
+            name = '.'.join((['croniter'] * i))
+            if name in sys.modules:
+                del sys.modules[name]
+
         old, sys.path = sys.path, []
         with self.assertRaises(ImportError):
             self.job.schedule(datetime(2001, 10, 11, 1, 12, 10))
