@@ -25,7 +25,7 @@ import sys
 sys.path.insert(0, '../')
 
 import unittest
-from crontab import CronTab, PY3
+from crontab import CronTab
 try:
     from test import test_support
 except ImportError:
@@ -33,9 +33,6 @@ except ImportError:
 
 TEST_DIR = os.path.dirname(__file__)
 
-if PY3:
-    unicode = str
-
 class EveryTestCase(unittest.TestCase):
     """Test basic functionality of crontab."""
     def setUp(self):
