@@ -25,15 +25,12 @@ import sys
 sys.path.insert(0, '../')
 
 import unittest
-from crontab import CronTab, PY3
+from crontab import CronTab
 try:
     from test import test_support
 except ImportError:
     from test import support as test_support
 
-if PY3:
-    unicode = str
-
 START_TAB = """
 """
 
