@@ -23,7 +23,7 @@ import re
 import os
 import unittest
 
-from crontab import CronTab, CronSlices, CronSlice, PY3
+from crontab import CronTab, CronSlices, CronSlice
 from .utils import LoggingMixin
 
 try:
@@ -33,9 +33,6 @@ except ImportError:
 
 TEST_DIR = os.path.dirname(__file__)
 
-if PY3:
-    unicode = str #pylint: disable=redefined-builtin
-
 COMMANDS = [
     'firstcommand',
     'range',
@@ -65,8 +62,8 @@ RESULT_TAB = """# First Comment
 @reboot rebooted # re-id
 # Last Comment @has this # extra
 
-# percent_one\\n* * * * * echo \% escaped
-# percent_two\\n* * * * * cat \%\% % stdin%with%lines
+# percent_one\\n* * * * * echo \\% escaped
+# percent_two\\n* * * * * cat \\%\\% % stdin%with%lines
 """
 
 class InteractionTestCase(LoggingMixin, unittest.TestCase):
@@ -164,10 +161,27 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         job.hour.also.every(4)
         self.assertEqual(job.render(), '* */4,1-4,2-10/4 * * * seq')
 
+    def test_09_new(self):
+        """Adding new Items at any order"""
+        thing1 = self.crontab.new('red', comment='thing1')
+        self.assertEqual(self.crontab[-1], thing1)
+        thing2 = self.crontab.new('blue', before=thing1)
+        self.assertEqual(self.crontab[-1], thing1)
+        self.assertEqual(self.crontab[-2], thing2)
+        thing3 = self.crontab.new('green', before='thing1')
+        self.assertEqual(self.crontab[-1], thing1)
+        self.assertEqual(self.crontab[-2], thing3)
+        self.assertEqual(self.crontab[-3], thing2)
+        thing4 = self.crontab.new('purple', before=re.compile('^thing'))
+        self.assertEqual(self.crontab[-2], thing4)
+        thing5 = self.crontab.new('black', before=self.crontab.find_command('blue'))
+        self.assertEqual(self.crontab[-5], thing5)
+        self.assertRaises(ValueError, self.crontab.new, 'fail', before='fail')
+
     def test_10_comment(self):
         """Render cron Comments"""
         job = self.crontab.new(command='com', comment='I love this')
-        self.assertEqual(unicode(job), '* * * * * com # I love this')
+        self.assertEqual(str(job), '* * * * * com # I love this')
 
     def test_11_disabled(self):
         """Disabled Job"""
@@ -180,9 +194,9 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         """Disable and Enable Job"""
         job = self.crontab.new(command='dis')
         job.enable(False)
-        self.assertEqual(unicode(job), '# * * * * * dis')
+        self.assertEqual(str(job), '# * * * * * dis')
         job.enable()
-        self.assertEqual(unicode(job), '* * * * * dis')
+        self.assertEqual(str(job), '* * * * * dis')
 
     def test_13_plural(self):
         """Plural API"""
@@ -191,7 +205,7 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         job.hours.on(5, 6)
         job.day.on(4)
         job.months.on(2)
-        self.assertEqual(unicode(job), '*/4 5,6 4 2 * plural')
+        self.assertEqual(str(job), '*/4 5,6 4 2 * plural')
 
     def test_14_valid(self):
         """Valid and Invalid"""
@@ -284,11 +298,11 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         for i in range(10):
             crontab = CronTab(tab=cron)
             p = list(crontab.new(command='multi%d' % i))
-            cron = unicode(crontab)
+            cron = str(crontab)
             crontab = CronTab(tab=cron)
             list(crontab.find_command('multi%d' % i))[0].delete()
-            cron = unicode(crontab)
-        self.assertEqual(unicode(crontab), '# start of tab\n')
+            cron = str(crontab)
+        self.assertEqual(str(crontab), '# start of tab\n')
 
     def test_22_min(self):
         """Minimum Field Values"""
@@ -297,7 +311,7 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         job.hour.on('<')
         job.dom.on('<')
         job.month.on('<')
-        self.assertEqual(unicode(job), '@yearly min')
+        self.assertEqual(str(job), '@yearly min')
 
     def test_23_max(self):
         """Maximum Field Values"""
@@ -306,7 +320,7 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         job.hour.on('>')
         job.dom.on('>')
         job.month.on('>')
-        self.assertEqual(unicode(job), '59 23 31 12 * max')
+        self.assertEqual(str(job), '59 23 31 12 * max')
 
     def test_24_special_r(self):
         """Special formats are read and written"""
@@ -330,13 +344,13 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         """Set all values at once"""
         job = self.crontab.new(command='all')
         job.setall(1, '*/2', '2-4', '>', 'SUN')
-        self.assertEqual(unicode(job), '1 */2 2-4 12 SUN all')
+        self.assertEqual(str(job), '1 */2 2-4 12 SUN all')
         job.setall('*/2')
-        self.assertEqual(unicode(job), '*/2 * * * * all')
+        self.assertEqual(str(job), '*/2 * * * * all')
         job.setall('1 */2 2-4 12 SUN')
-        self.assertEqual(unicode(job), '1 */2 2-4 12 SUN all')
+        self.assertEqual(str(job), '1 */2 2-4 12 SUN all')
         job.setall(['*'])
-        self.assertEqual(unicode(job), '* * * * * all')
+        self.assertEqual(str(job), '* * * * * all')
 
     def test_26_setall_obj(self):
         """Copy all values"""
@@ -344,10 +358,10 @@ class InteractionTestCase(LoggingMixin, unittest.TestCase):
         job2 = self.crontab.new(command='ignore')
         job2.setall("1 */2 2-4 12 SUN")
         job.setall(job2)
-        self.assertEqual(unicode(job), '1 */2 2-4 12 SUN all')
+        self.assertEqual(str(job), '1 */2 2-4 12 SUN all')
         job2.setall("2 */3 4-8 10 MON")
         job.setall(job2.slices)
-        self.assertEqual(unicode(job), '2 */3 4-8 10 MON all')
+        self.assertEqual(str(job), '2 */3 4-8 10 MON all')
 
     def test_27_commands(self):
         """Get all commands"""
