@@ -74,7 +74,7 @@ class UseTestCase(unittest.TestCase):
         """Open system crontab"""
         cron = crontab.CronTab()
         self.assertEqual(cron.render(), "")
-        self.assertEqual(cron.__unicode__(), "")
+        self.assertEqual(cron.__str__(), "")
         self.assertEqual(repr(cron), "<Unattached CronTab>")
 
     def test_02_user(self):
@@ -198,6 +198,8 @@ class UseTestCase(unittest.TestCase):
         self.assertFalse(CronSlices.is_valid('* * * * FRO-TOO'))
         self.assertFalse(CronSlices.is_valid('@retool'))
 
+        self.assertRaises(ValueError, CronSlices._parse_value, None)
+
     def test_21_slice_special(self):
         """Rendering can be done without specials"""
         cronitem = crontab.CronItem('true')
